@@ -1,6 +1,7 @@
 #include <algorithm>
 #include <string>
 #include <R.h>
+#include <Rmath.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
 #include <R_ext/Lapack.h>
@@ -18,15 +19,10 @@ extern "C" {
     /*****************************************
                 Common variables
     *****************************************/
-    int i,j,k,l,b,info,nProtect= 0;
+    int i,j,k,b,info,nProtect= 0;
     char const *lower = "L";
-    char const *upper = "U";
     char const *ntran = "N";
-    char const *ytran = "T";
-    char const *rside = "R";
-    char const *lside = "L";
     const double one = 1.0;
-    const double negOne = -1.0;
     const double zero = 0.0;
     const int incOne = 1;
 
@@ -37,7 +33,6 @@ extern "C" {
     double *Y = REAL(Y_r);
     double *X = REAL(X_r);
     int p = INTEGER(p_r)[0];
-    int pp = p*p;
     int n = INTEGER(n_r)[0];
 
     double *coordsD = REAL(coordsD_r);
@@ -131,7 +126,7 @@ extern "C" {
     int nn = n*n;
 
     //spatial parameters
-    int nParams, betaIndx, sigmaSqIndx, phiIndx, nuIndx;
+    int nParams, betaIndx, sigmaSqIndx, phiIndx, nuIndx = 0;
 
     if(covModel != "matern"){
       nParams = p+2;//sigma^2, phi
@@ -200,7 +195,7 @@ extern "C" {
     double *tmp_n = (double *) R_alloc(n, sizeof(double));
     double *tmp_n1 = (double *) R_alloc(n, sizeof(double));
 
-    double sigmaSq, phi, nu;
+    double sigmaSq, phi, nu = 0;
     double *beta = (double *) R_alloc(p, sizeof(double));
     double *theta = (double *) R_alloc(3, sizeof(double)); //phi, nu, and perhaps more in the future
 
