@@ -18,15 +18,12 @@ extern "C" {
     /*****************************************
                 Common variables
     *****************************************/
-    int h, i, j, k, l, b, s, ii, jj, info, nProtect= 0;
+    int h, i, j, k, l, s, ii, jj, info, nProtect= 0;
     const char *lower = "L";
-    const char *upper = "U";
     const char *ntran = "N";
     const char *ytran = "T";
-    const char *rside = "R";
     const char *lside = "L";
     const double one = 1.0;
-    const double negOne = -1.0;
     const double zero = 0.0;
     const int incOne = 1;
 
@@ -35,8 +32,6 @@ extern "C" {
     *****************************************/
 
     std::string family = CHAR(STRING_ELT(family_r,0));
-    double *Y = REAL(Y_r);
-    double *X = REAL(X_r);
     int n = INTEGER(n_r)[0];
     int m = INTEGER(m_r)[0];
     int p = INTEGER(p_r)[0];
@@ -58,7 +53,7 @@ extern "C" {
          Set-up sample matrices etc.
     *****************************************/
     //spatial parameters
-    int nParams, betaIndx, AIndx, phiIndx, nuIndx;
+    int nParams, betaIndx, AIndx, phiIndx, nuIndx = 0;
 
     if(covModel != "matern"){
       nParams = p+nLTr+m;//A, phi
@@ -73,7 +68,6 @@ extern "C" {
     int nmnm = nm*nm;
     int qm = q*m;
     int qmnm = qm*nm;
-    int qmqm = qm*qm;
     int nmm = nm*m;
 
     SEXP wPred_r, yPred_r;
