@@ -4,6 +4,7 @@
 // #include <omp.h>
 // #endif
 #include <R.h>
+#include <Rmath.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
 #include <R_ext/Lapack.h>
@@ -26,9 +27,7 @@ extern "C" {
     *****************************************/
     int h, i, j, k, l, b, s, ii, jj, info, nProtect= 0;
     char const *lower = "L";
-    char const *upper = "U";
     char const *nUnit = "N";
-    char const *yUnit = "U";
     char const *ntran = "N";
     char const *ytran = "T";
     char const *rside = "R";
@@ -47,7 +46,6 @@ extern "C" {
     int n = INTEGER(n_r)[0];
     int m = INTEGER(m_r)[0];
     int nLTr = m*(m-1)/2+m;
-    int nn = n*n;
     int mm = m*m;
     int nm = n*m;
     int nmnm = nm*nm;
@@ -231,7 +229,7 @@ extern "C" {
          Set-up MCMC sample matrices etc.
     *****************************************/
     //spatial parameters
-    int nParams, AIndx, LIndx, phiIndx, nuIndx;
+    int nParams, AIndx, LIndx = 0, phiIndx, nuIndx = 0;
 
     if(!nugget && covModel != "matern"){
       nParams = nLTr+m;//A, phi
@@ -348,8 +346,6 @@ extern "C" {
     double *accept = (double *) R_alloc(nParams, sizeof(double)); zeros(accept, nParams);
 
     double *C = (double *) R_alloc(nmnm, sizeof(double)); 
-
-    double *K = (double *) R_alloc(mm, sizeof(double));
     double *Psi = (double *) R_alloc(mm, sizeof(double));
     double *A = (double *) R_alloc(mm, sizeof(double));
     double *L = (double *) R_alloc(mm, sizeof(double));
