@@ -4,6 +4,7 @@
 // #include <omp.h>
 // #endif
 #include <R.h>
+#include <Rmath.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
 #include <R_ext/Lapack.h>
@@ -25,13 +26,11 @@ extern "C" {
     *****************************************/
     int h, i, j, k, l, b, s, ii, jj, info, nProtect= 0;
     char const *lower = "L";
-    char const *upper = "U";
     char const *ntran = "N";
     char const *ytran = "T";
     char const *rside = "R";
     char const *lside = "L";
     const double one = 1.0;
-    const double negOne = -1.0;
     const double zero = 0.0;
     const int incOne = 1;
 
@@ -41,15 +40,11 @@ extern "C" {
     double *Y = REAL(Y_r);
     double *X = REAL(X_r);
     int p = INTEGER(p_r)[0];
-    int pp = p*p;
     int n = INTEGER(n_r)[0];
     int m = INTEGER(m_r)[0];
     int q = INTEGER(q_r)[0];
-    int nn = n*n;
     int mm = m*m;
     int nm = n*m;
-    int nq = n*q;
-    int qq = q*q;
     int qm = q*m;
     int qmqm = qm*qm;
     int nLTr = m*(m-1)/2+m;
@@ -173,7 +168,7 @@ extern "C" {
          Set-up MCMC sample matrices etc.
     *****************************************/
     //spatial parameters
-    int nParams, betaIndx, AIndx, phiIndx, nuIndx;
+    int nParams, betaIndx, AIndx, phiIndx, nuIndx = 0;
 
     if(covModel != "matern"){
       nParams = p+nLTr+m;//A, phi
@@ -251,7 +246,6 @@ extern "C" {
     double *K = (double *) R_alloc(qmqm, sizeof(double));
 
     double *tmp_mm = (double *) R_alloc(mm, sizeof(double));
-    double *tmp_mm1 = (double *) R_alloc(mm, sizeof(double));
     double *tmp_nm = (double *) R_alloc(nm, sizeof(double));
     double *tmp_qm = (double *) R_alloc(qm, sizeof(double));
     double *tmp_nmqm = (double *) R_alloc(nm*qm, sizeof(double));
